@@ -1,11 +1,11 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::NextRelease::Grouped;
 
 # ABSTRACT: Simplify usage of a grouped changelog
-our $VERSION = '0.0102';
+our $VERSION = '0.0200';
 
 use Moose;
 use MooseX::AttributeShortcuts;
@@ -97,7 +97,7 @@ has groups => (
 has auto_order => (
     is => 'ro',
     isa => Bool,
-    default => 0,
+    default => 1,
 );
 
 has _changes_after_munging => (
@@ -139,14 +139,50 @@ sub munge_files {
 
     my $sort_groups = sub {
         my @custom_groups = grep { my $group = $_; none { $group eq $_ } $self->all_groups } @_;
-
-        return  map  { $_->name             }
-                grep { !$_->is_empty        }
-                map  { $next->get_group($_) }
-                @custom_groups, $self->all_groups;
+        my @sorted = ((sort { $a cmp $b } @custom_groups), $self->all_groups);
+        return @sorted;
     };
 
     my $content = $self->auto_order ? $changes->serialize : $changes->serialize(group_sort => $sort_groups);
+
+    # hack to remove empty groups
+    if(!$self->auto_order) {
+
+        # followed by another group
+        $content =~ s{
+            (?<= [\n\r] )
+              [\s\t]+ \[ [^\]]+ \] [\s\t]*
+              [\n\r]+
+            (?= [\s\t]+ \[ [^\]]+ \] )
+            }{\n}xmsg;
+
+        # followed by a release
+        $content =~ s{
+            (?<=[\n\r])
+            [\s\t]+ \[ [^\]]+ \] [\s\t]*
+            [\n\r]+
+            (?=[v\d])
+            }{\n}xmsg;
+
+        # followed by end-of-file
+        $content =~ s{
+            (?<= [\n\r])
+            [\s\t]+ \[ [^\]]+ \] [\s\t]*
+            [\n\r]*
+            \z
+            }{\n}xmsg;
+
+        # just one final \n
+        $content =~ s{\n+\z}{\n}ms;
+
+        # cleanup whitespace
+        $content =~ s{\r}{}g;
+        $content =~ s{\n{3,}}{\n\n}g;
+
+        # ensure that a release header (any line starting with \d or 'v') isn't followed by an empty line.
+        $content =~ s{(\n [v\d] [^\n]+) \n{2,} (?=[\s\t]) }{$1\n}msgx;
+    }
+
     $file->content($content);
     $self->_changes_after_munging($content);
 }
@@ -192,20 +228,20 @@ Dist::Zilla::Plugin::NextRelease::Grouped - Simplify usage of a grouped changelo
 
 =begin HTML
 
-<p><img src="https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg" alt="Requires Perl 5.10.1+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Zilla-Plugin-NextRelease-Grouped"><img src="https://api.travis-ci.org/Csson/p5-Dist-Zilla-Plugin-NextRelease-Grouped.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-79.3%-orange.svg" alt="coverage 79.3%" /></p>
+<p><img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Zilla-Plugin-NextRelease-Grouped"><img src="https://api.travis-ci.org/Csson/p5-Dist-Zilla-Plugin-NextRelease-Grouped.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-79.9%-orange.svg" alt="coverage 79.9%" /></p>
 
 =end HTML
 
 
 =begin markdown
 
-![Requires Perl 5.10.1+](https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Zilla-Plugin-NextRelease-Grouped.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Zilla-Plugin-NextRelease-Grouped) ![coverage 79.3%](https://img.shields.io/badge/coverage-79.3%-orange.svg)
+![Requires Perl 5.10+](https://img.shields.io/badge/perl-5.10+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Zilla-Plugin-NextRelease-Grouped.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Zilla-Plugin-NextRelease-Grouped) ![coverage 79.9%](https://img.shields.io/badge/coverage-79.9%-orange.svg)
 
 =end markdown
 
 =head1 VERSION
 
-Version 0.0102, released 2016-02-12.
+Version 0.0200, released 2016-02-15.
 
 =head1 SYNOPSIS
 
@@ -282,10 +318,13 @@ The name of the stash where the user's name and email can be found.
 
 =item C<auto_order>
 
-Default: C<0>
+Default: C<1>
 
 If true, the groups are ordered alphabetically. If false, the groups are ordered in the order they are given to C<groups>.
 
+Note: If it is false, it also munges the changelog to ensure that one-off groups aren't deleted (while empty groups are). This might be
+a source of bugs.
+
 =back
 
 =head1 ACKNOWLEDGMENTS
